@@ -438,6 +438,9 @@ def interface_custom_mask_focus_field_XZ_XY(n_list,d_list,ex_lens,ey_lens,alpha,
     Axx=-prefactor_x*ex_lens*weight_trapezoid
     Axy=prefactor_y*ex_lens*weight_trapezoid
     Axz=prefactor_z*ex_lens*weight_trapezoid
+    print(f"{np.mean(Axx)=}")
+    print(f"{np.mean(Axy)=}")
+    print(f"{np.mean(Axz)=}")
 
     Ayx=prefactor_y*ey_lens*weight_trapezoid
     Ayy=prefactor_x*ey_lens*weight_trapezoid
@@ -517,6 +520,13 @@ def interface_custom_mask_focus_field_XZ_XY(n_list,d_list,ex_lens,ey_lens,alpha,
     theta_values=np.linspace(0,alpha,divisions_theta)    
     phi_values=np.linspace(0,2*np.pi,divisions_phi) 
     theta,phi=np.meshgrid(theta_values,phi_values)
+
+    # for i, val in enumerate([Axx, Axy, Axz, Ayx, Ayy, Ayz, Axx_r, Axy_r, Axz_r, Ayx_r, Ayy_r, Ayz_r, Axx_t, Axy_t, Axz_t, Ayx_t, Ayy_t, Ayz_t, cos_theta, cos_theta_t, sin_theta, phi, k1, k2]):
+    #     if isinstance(val, float) or isinstance(val, int):
+    #         print(f"{i} {val}")
+    #     else:
+    #         print(f"{i} {np.mean(val)}")
+
     if plot_plane=='X':
         for j in tqdm(range(resolution_z)):
             zp0=z_values[j]
